package nm

import (
	"bytes"
	"encoding/json"
	"fmt"
	"gdyb/controllers"
	"gdyb/enums"
	"gdyb/models"
	"gdyb/service"
	"gdyb/utils"
	"github.com/astaxie/beego"
	"github.com/axgle/mahonia"
	"github.com/gorilla/websocket"
	"golang.org/x/text/encoding/simplifiedchinese"
	"io/ioutil"
	"log"
	"net/http"
	"net/url"
	"os"
	"regexp"
	"strconv"
	"strings"
	"syscall"
	"time"
	"unsafe"
)

type NmController struct {
	controllers.BaseAuthAPIController
}

func NmybRegistRouters() {
	beego.Router("/nmyb/1101", &NmController{}, "get:Post1101")
	beego.Router("/nmyb/2401", &NmController{}, "post:Post2401")
	beego.Router("/nmyb/2402", &NmController{}, "post:Post2402")
	beego.Router("/nmyb/2404", &NmController{}, "get:Post2404")
	beego.Router("/nmyb/2405", &NmController{}, "get:Post2405")
	beego.Router("/nmyb/2301", &NmController{}, "post:Post2301")
	beego.Router("/nmyb/2302", &NmController{}, "get:Post2302")
	beego.Router("/nmyb/2303", &NmController{}, "get:Post2303")
	beego.Router("/nmyb/2304", &NmController{}, "get:Post2304")
	beego.Router("/nmyb/2305", &NmController{}, "get:Post2305")
	beego.Router("/nmyb/5203", &NmController{}, "get:Post5203")
	beego.Router("/nmyb/readcard", &NmController{}, "get:ReadCard")
	beego.Router("/nmyb/3201", &NmController{}, "get:Get3201")
	beego.Router("/nmyb/4101", &NmController{}, "post:Post4101")
	beego.Router("/nmyb/2601", &NmController{}, "get:Get2601")
	beego.Router("/api/token", &NmController{}, "get:GetToken")
	//beego.Router("/api/eleinfo", &NmController{}, "get:GetNewELeInfo")
	beego.Router("/nmyb/4102", &NmController{}, "get:Post4102")
	beego.Router("/nmyb/4103", &NmController{}, "get:Post4103")

	beego.Router("/nmyb/2201", &NmController{}, "get:Post2201")
	beego.Router("/nmyb/2202", &NmController{}, "get:Post2202")
	beego.Router("/nmyb/2203", &NmController{}, "post:Post2203")
	beego.Router("/nmyb/2203C", &NmController{}, "post:Post2203C")

	beego.Router("/nmyb/2204", &NmController{}, "post:Post2204")
	beego.Router("/nmyb/2205", &NmController{}, "get:Post2205")
	beego.Router("/nmyb/2206", &NmController{}, "get:Post2206")
	beego.Router("/nmyb/2207", &NmController{}, "get:Post2207")
	beego.Router("/nmyb/2208", &NmController{}, "get:Post2208")

	beego.Router("/nmyb/2503", &NmController{}, "get:Post2503")

}

func (c *NmController) Post2201() {
	psnNo := c.GetString("psn_no")
	insutype := c.GetString("insutype")
	certNo := c.GetString("cert_no")
	org_name := c.GetString("org_name")
	ipt_otp_no := c.GetString("ipt_otp_no")
	dept := c.GetString("dept")
	verify_number := c.GetString("verify_number")
	fixmedins_code := c.GetString("fixmedins_code")
	dept_code := c.GetString("dept_code")
	doctor_id := c.GetString("doctor_id")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	id_card_type, _ := c.GetInt64("id_card_type")
	doctor_name := c.GetString("doctor_name")
	cainfo := c.GetString("cainfo")
	opter := c.GetString("opter")

	result, request_log := service.Nmyb2201(psnNo, insutype, certNo, org_name, opter, ipt_otp_no, dept, fixmedins_code, dept_code, doctor_id, insuplc_admdvs, mdtrtarea_admvs, secret_key, id_card_type, doctor_name, verify_number, cainfo)
	saveJsLog(result, request_log, "2201", "挂号", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {
	} else {
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2202() {
	psnNo := c.GetString("psn_no")
	mdtrtId := c.GetString("mdtrt_id")
	iptOtpNo := c.GetString("ipt_otp_no")
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	fixmedins_code := c.GetString("fixmedins_code")
	cainfo := c.GetString("cainfo")

	result, request_log := service.Nmyb2202(psnNo, mdtrtId, iptOtpNo, org_name, doctor, insuplc_admdvs, mdtrtarea_admvs, secret_key, fixmedins_code, cainfo)
	saveJsLog(result, request_log, "2202", "退号", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}

	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {

	} else {

	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2203() {

	body, _ := ioutil.ReadAll(c.Ctx.Request.Body)
	var respJSON map[string]interface{}
	if err := json.Unmarshal([]byte(string(body)), &respJSON); err != nil {
		utils.ErrorLog("接口返回数据解析JSON失败: %v", err)
		return
	}
	userJSONBytes, _ := json.Marshal(respJSON["config"])
	var config []*models.HisXtDiagnoseConfig
	if err := json.Unmarshal(userJSONBytes, &config); err != nil {
		utils.ErrorLog("解析失败：%v", err)
		return
	}
	fmt.Println(respJSON["psn_no"].(string))
	fmt.Println(respJSON["mdtrt_id"].(string))

	psnNo := respJSON["psn_no"].(string)
	mdtrtId := respJSON["mdtrt_id"].(string)
	doctor := respJSON["doctor"].(string)
	department := respJSON["department"].(string)

	org_name := respJSON["org_name"].(string)
	med_type := respJSON["med_type"].(string)
	doctor_id := respJSON["doctor_id"].(string)
	fixmedins_code := respJSON["fixmedins_code"].(string)
	sick_code := respJSON["sick_code"].(string)
	sick_name := respJSON["sick_name"].(string)
	dept := respJSON["dept"].(string)

	insuplc_admdvs := respJSON["insuplc_admdvs"].(string)
	mdtrtarea_admvs := respJSON["mdtrtarea_admvs"].(string)
	secret_key := respJSON["secret_key"].(string)

	begin_time := respJSON["begin_time"].(string)
	cainfo := respJSON["cainfo"].(string)

	//cainfo := c.GetString("cainfo")

	result, request_log := service.Nmyb2203(psnNo, mdtrtId, doctor, department, org_name, med_type, doctor_id, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, sick_code, sick_name, dept, config, begin_time, cainfo)
	saveJsLog(result, request_log, "2203", "上传就诊信息", org_name)
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {

	} else {

	}

	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {

	} else {

	}

	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2203C() {

	body, _ := ioutil.ReadAll(c.Ctx.Request.Body)
	var respJSON map[string]interface{}
	if err := json.Unmarshal([]byte(string(body)), &respJSON); err != nil {
		utils.ErrorLog("接口返回数据解析JSON失败: %v", err)
		return
	}
	userJSONBytes, _ := json.Marshal(respJSON["config"])
	var config []*models.HisXtDiagnoseConfig
	if err := json.Unmarshal(userJSONBytes, &config); err != nil {
		utils.ErrorLog("解析失败：%v", err)
		return
	}
	fmt.Println(respJSON["psn_no"].(string))
	fmt.Println(respJSON["mdtrt_id"].(string))

	psnNo := respJSON["psn_no"].(string)
	mdtrtId := respJSON["mdtrt_id"].(string)
	doctor := respJSON["doctor"].(string)
	department := respJSON["department"].(string)

	org_name := respJSON["org_name"].(string)
	med_type := respJSON["med_type"].(string)
	doctor_id := respJSON["doctor_id"].(string)
	fixmedins_code := respJSON["fixmedins_code"].(string)
	sick_code := respJSON["sick_code"].(string)
	sick_name := respJSON["sick_name"].(string)
	dept := respJSON["dept"].(string)

	insuplc_admdvs := respJSON["insuplc_admdvs"].(string)
	mdtrtarea_admvs := respJSON["mdtrtarea_admvs"].(string)
	secret_key := respJSON["secret_key"].(string)

	begin_time := respJSON["begin_time"].(string)
	cainfo := respJSON["cainfo"].(string)
	//is_vaild := respJSON["is_vaild"].(string)

	//cainfo := c.GetString("cainfo")

	result, request_log := service.Nmyb2203C(psnNo, mdtrtId, doctor, department, org_name, med_type, doctor_id, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, sick_code, sick_name, dept, config, begin_time, cainfo)
	saveJsLog(result, request_log, "2203", "上传就诊信息", org_name)
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {

	} else {

	}

	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {

	} else {

	}

	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}

func (c *NmController) Post2204() {
	body, _ := ioutil.ReadAll(c.Ctx.Request.Body)
	var respJSON map[string]interface{}
	if err := json.Unmarshal([]byte(string(body)), &respJSON); err != nil {
		utils.ErrorLog("接口返回数据解析JSON失败: %v", err)
		return
	}
	userJSONBytes, _ := json.Marshal(respJSON["pre"])
	var hp []*models.HisPrescription
	if err := json.Unmarshal(userJSONBytes, &hp); err != nil {
		utils.ErrorLog("解析失败：%v", err)
		return
	}
	//fmt.Println("2203A的time_stamp=" + respJSON["time_stamp"].(string))
	result, request_log := service.Nmyb2204(respJSON["psn_no"].(string), respJSON["mdtrt_id"].(string), hp, respJSON["chrg_bchno"].(string), respJSON["org_name"].(string),
		respJSON["doctor"].(string), respJSON["dept"].(string), respJSON["fixmedins_code"].(string), respJSON["dept_code"].(string), respJSON["doctor_id"].(string), respJSON["insuplc_admdvs"].(string), respJSON["mdtrtarea_admvs"].(string), respJSON["secret_key"].(string), respJSON["balance_accounts_type"].(string), respJSON["diag_code"].(string), respJSON["url"].(string), respJSON["ak"].(string), respJSON["new_doctor_name"].(string), "", respJSON["cainfo"].(string))

	saveJsLog(result, request_log, "2204", "上传明细", respJSON["org_name"].(string))
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
		fmt.Println(dat)
	} else {
		fmt.Println(err)
	}

	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {
		fmt.Println(dat2)
	} else {
		fmt.Println(err)
	}

	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2205() {
	psnNo := c.GetString("psn_no")
	mdtrtId := c.GetString("mdtrt_id")
	chrgBchno := c.GetString("chrg_bchno")
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")

	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")

	secret_key := c.GetString("secret_key")
	fixmedins_code := c.GetString("fixmedins_code")
	url := c.GetString("url")
	ak := c.GetString("ak")
	cainfo := c.GetString("cainfo")

	result, request_log := service.Nmyb2205(psnNo, mdtrtId, chrgBchno, org_name, doctor, insuplc_admdvs, mdtrtarea_admvs, secret_key, fixmedins_code, url, ak, cainfo)
	fmt.Println(request_log)
	saveJsLog(result, request_log, "2205", "撤销明细", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
		fmt.Println(dat)
	} else {
		fmt.Println(err)
	}
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {
		fmt.Println(dat2)
	} else {
		fmt.Println(err)
	}

	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2206() {
	psnNo := c.GetString("psn_no")
	mdtrtId := c.GetString("mdtrt_id")
	chrgBchno := c.GetString("chrg_bchno")
	certNo := c.GetString("cert_no")
	insutype := c.GetString("insutype")
	total := c.GetString("total")
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	med_type := c.GetString("med_type")
	id_card_type, _ := c.GetInt64("id_card_type")
	certificates, _ := c.GetInt64("certificates")
	verify_number := c.GetString("verify_number")
	cainfo := c.GetString("cainfo")
	mdtrt_grp_type := c.GetString("mdtrt_grp_type")

	url := c.GetString("url")
	ak := c.GetString("ak")

	var result string
	var request_log string

	result, request_log = service.Nmyb2206(psnNo, mdtrtId, chrgBchno, certNo, insutype, total, org_name, doctor, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, med_type, id_card_type, 0, 0, 0, 0, certificates, url, ak, verify_number, cainfo, mdtrt_grp_type)

	saveJsLog(result, request_log, "2206", "预结算", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
		fmt.Println(dat)
	} else {
		fmt.Println(err)
	}

	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {
		fmt.Println(dat2)
	} else {
		fmt.Println(err)
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2207() {
	psnNo := c.GetString("psn_no")
	mdtrtId := c.GetString("mdtrt_id")
	chrgBchno := c.GetString("chrg_bchno")
	certNo := c.GetString("cert_no")
	insutype := c.GetString("insutype")
	total := c.GetString("total")
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	med_type := c.GetString("med_type")
	id_card_type, _ := c.GetInt64("id_card_type")
	certificates, _ := c.GetInt64("certificates")

	fulamt_ownpay_amt, _ := c.GetFloat("fulamt_ownpay_amt")
	overlmt_selfpay, _ := c.GetFloat("overlmt_selfpay")
	preselfpay_amt, _ := c.GetFloat("preselfpay_amt")
	inscp_scp_amt, _ := c.GetFloat("inscp_scp_amt")

	acct_used_flag := c.GetString("acct_used_flag")

	url := c.GetString("url")
	ak := c.GetString("ak")
	verify_number := c.GetString("verify_number")
	cainfo := c.GetString("cainfo")
	mdtrt_grp_type := c.GetString("mdtrt_grp_type")

	var result string
	var request_log string

	result, request_log = service.Nmyb2207(psnNo, mdtrtId, chrgBchno, certNo, insutype, total, org_name, doctor, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, med_type, id_card_type, fulamt_ownpay_amt, overlmt_selfpay, preselfpay_amt, inscp_scp_amt, certificates, acct_used_flag, url, ak, verify_number, cainfo, mdtrt_grp_type)

	saveJsLog(result, request_log, "2207", "结算", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
		fmt.Println(dat)
	} else {
		fmt.Println(err)
	}

	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {
		fmt.Println(dat2)
	} else {
		fmt.Println(err)
	}

	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2208() {
	psnNo := c.GetString("psn_no")
	mdtrtId := c.GetString("mdtrt_id")
	setlId := c.GetString("setl_id")
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")
	secret_key := c.GetString("secret_key")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	url := c.GetString("url")
	ak := c.GetString("ak")
	cainfo := c.GetString("cainfo")

	result, request_log := service.Nmyb2208(psnNo, mdtrtId, setlId, org_name, doctor, secret_key, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, url, ak, cainfo)
	saveJsLog(result, request_log, "2208", "退费", org_name)
	fmt.Println(request_log)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
		fmt.Println(dat)
	} else {
		fmt.Println(err)
	}
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {
		fmt.Println(dat2)
	} else {
		fmt.Println(err)
	}

	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2503() {
	psnNo := c.GetString("psn_no")
	insutype := c.GetString("insutype")
	opera := c.GetString("opera")
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")
	doctor_id := c.GetString("doctor_id")
	secret_key := c.GetString("secret_key")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	sick_name := c.GetString("sick_name")
	sick_code := c.GetString("sick_code")
	start_time := c.GetString("start_time")
	end_time := c.GetString("end_time")
	check_time := c.GetString("check_time")
	hospital_name := c.GetString("hospital_name")
	hospital_code := c.GetString("hospital_code")

	result := service.Nmyb2503(psnNo, insutype, org_name, opera, doctor, fixmedins_code, doctor_id, insuplc_admdvs, mdtrtarea_admvs, secret_key, sick_name, sick_code, start_time, end_time, check_time, hospital_code, hospital_name)

	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
		fmt.Println(dat)
	} else {
		fmt.Println(err)
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
	})
}

//func (c *NmController) GetNewELeInfo() {
//	token := c.GetString("token")
//	user_name := c.GetString("user_name")
//	id_card_no := c.GetString("id_card_no")
//
//	result, _ := service.Gdyb1101ForEleCert("赤峰费森血液透析中心", "关学丽", "H15049901371", "150499", "150499", "MSDBYGxXm1Mtyi3PtOUB7n1ktcxwyW57", token, user_name, id_card_no)
//	var dat map[string]interface{}
//	if err := json.Unmarshal([]byte(result), &dat); err == nil {
//		fmt.Println(dat)
//	} else {
//		fmt.Println(err)
//	}
//	userJSONBytes, _ := json.Marshal(dat)
//	var res ResultTwo
//
//	if err := json.Unmarshal(userJSONBytes, &res); err != nil {
//		utils.ErrorLog("解析失败：%v", err)
//		c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeDataException)
//		return
//	}
//
//	infocode, _ := strconv.ParseInt(res.Infcode, 10, 64)
//	if infocode == 0 {
//		data := make(map[string]interface{})
//		data["token"] = token
//		data["result"] = dat
//		var req *http.Request
//		bytesData, _ := json.Marshal(data)
//		req, _ = http.NewRequest("POST", "http://172.16.13.253:9532/"+"api/ele/info", bytes.NewReader(bytesData))
//		client := &http.Client{}
//		resp, _ := client.Do(req)
//		defer resp.Body.Close()
//		body, ioErr := ioutil.ReadAll(resp.Body)
//		if ioErr != nil {
//			utils.ErrorLog("接口返回数据读取失败: %v", ioErr)
//			c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeDataException)
//			return
//		}
//		var respJSON map[string]interface{}
//		if err := json.Unmarshal([]byte(body), &respJSON); err != nil {
//			utils.ErrorLog("接口返回数据解析JSON失败: %v", err)
//			c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeDataException)
//			return
//		}
//		c.ServeSuccessJSON(map[string]interface{}{
//			"msg": "成功",
//		})
//
//	}
//}
func (c *NmController) GetToken() {
	token := c.GetString("token")
	results := strings.Split(token, "-")
	fmt.Println(token)
	result_code := results[0]
	result_info := results[1]
	if result_code == "0000" {

		var ele2 ELeData2
		err := json.Unmarshal([]byte(result_info), &ele2)
		if err != nil {
			utils.ErrorLog("解析失败：%v", err)
		}

		if ele2.Code != -2 {
			var ele ELeData
			err := json.Unmarshal([]byte(result_info), &ele)
			if err != nil {
				utils.ErrorLog("解析失败：%v", err)
			}
			token := ele.Data.EcToken

			if len(token) > 0 {
				data := make(map[string]interface{})
				data["token"] = token
				data["id_card_no"] = ele.Data.IdNo
				fmt.Println(data)
				var req *http.Request
				fmt.Println(req)

				bytesData, _ := json.Marshal(data)
				fmt.Println(bytesData)

				req, _ = http.NewRequest("POST", "http://172.16.13.253:9532/"+"api/token/get", bytes.NewReader(bytesData))
				fmt.Println(req)
				client := &http.Client{}
				resp, _ := client.Do(req)
				fmt.Println(resp)

				defer resp.Body.Close()
				body, ioErr := ioutil.ReadAll(resp.Body)
				fmt.Println(resp.Body)
				fmt.Println(body)
				fmt.Println(ioErr)
				if ioErr != nil {
					utils.ErrorLog("接口返回数据读取失败: %v", ioErr)
					c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeDataException)
					return
				}
				var respJSON map[string]interface{}
				if err := json.Unmarshal([]byte(body), &respJSON); err != nil {
					utils.ErrorLog("接口返回数据解析JSON失败: %v", err)
					c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeDataException)
					return
				}

			} else {
				c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeHisFailedException)
				return
			}

		}

	} else {
		c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeHisFailedException)
		return
	}

}

type ReadCardResult struct {
	Output struct {
		CardInfo   string `json:"cardInfo"`
		RegionCode string `json:"regionCode"`
	} `json:"output"`
	Code   string `json:"CODE"`
	ErrMsg string `json:"ERRMSG"`
}

type ELeData2 struct {
	Code    int    `json:"code"`
	Message string `json:"message"`
}
type ELeData struct {
	Data struct {
		IdNo        string `json:"idNo"`
		IdType      string `json:"idType"`
		UserName    string `json:"userName"`
		EcToken     string `json:"ecToken"`
		InsuOrg     string `json:"insuOrg"`
		Gender      string `json:"gender"`
		Birthday    string `json:"birthday"`
		Nationality string `json:"nationality"`
		Email       string `json:"email"`
		Extra       string `json:"extra"`
	} `json:"data"`
	Code    int    `json:"code"`
	Message string `json:"message"`
}

type ResultTwo struct {
	ErrMsg      string `json:"err_msg"`
	InfRefmsgid string `json:"inf_refmsgid"`
	Infcode     string `json:"infcode"`
	Output      struct {
		Baseinfo struct {
			Age         float64 `json:"age"`
			Brdy        string  `json:"brdy"`
			Certno      string  `json:"certno"`
			Gend        string  `json:"gend"`
			Naty        string  `json:"naty"`
			PsnCertType string  `json:"psn_cert_type"`
			PsnName     string  `json:"psn_name"`
			PsnNo       string  `json:"psn_no"`
		} `json:"baseinfo"`
		Idetinfo []interface{} `json:"idetinfo"`
		Iinfo    []struct {
			Balc                   float64 `json:"balc"`
			CvlservFlag            string  `json:"cvlserv_flag"`
			EmpName                string  `json:"emp_name"`
			InsuplcAdmdvs          string  `json:"insuplc_admdvs"`
			Insutype               string  `json:"insutype"`
			PausInsuDansuplcAdmdvs string  `json:"paus_insu_dansuplc_admdvs"`
			PausInsuDate           string  `json:"paus_insu_date"`
			PsnInsuDate            string  `json:"psn_insu_date"`
			PsnInsuStas            string  `json:"psn_insu_stas"`
			PsnType                string  `json:"psn_type"`
		} `json:"insuinfo"`
	} `json:"output"`
	RefmsgTime  string      `json:"refmsg_time"`
	RespondTime string      `json:"respond_time"`
	Signtype    interface{} `json:"signtype"`
	WarnInfo    interface{} `json:"warn_info"`
}
type ResultTwo10265 struct {
	ErrMsg      string `json:"err_msg"`
	InfRefmsgid string `json:"inf_refmsgid"`
	Infcode     string `json:"infcode"`
	Output      struct {
		Baseinfo struct {
			Age         float64 `json:"age"`
			Brdy        string  `json:"brdy"`
			Certno      string  `json:"certno"`
			Gend        string  `json:"gend"`
			Naty        string  `json:"naty"`
			PsnCertType string  `json:"psn_cert_type"`
			PsnName     string  `json:"psn_name"`
			PsnNo       string  `json:"psn_no"`
		} `json:"baseinfo"`
		Idetinfo []interface{} `json:"idetinfo"`
		Iinfo    []struct {
			Balc                   float64 `json:"balc"`
			CvlservFlag            string  `json:"cvlserv_flag"`
			EmpName                string  `json:"emp_name"`
			InsuplcAdmdvs          string  `json:"insuplc_admdvs"`
			Insutype               string  `json:"insutype"`
			PausInsuDansuplcAdmdvs string  `json:"paus_insu_dansuplc_admdvs"`
			PausInsuDate           string  `json:"paus_insu_date"`
			PsnInsuDate            string  `json:"psn_insu_date"`
			PsnInsuStas            string  `json:"psn_insu_stas"`
			PsnType                string  `json:"psn_type"`
		} `json:"insuinfo"`
	} `json:"output"`
	RefmsgTime  string      `json:"refmsg_time"`
	RespondTime string      `json:"respond_time"`
	Signtype    interface{} `json:"signtype"`
	WarnInfo    interface{} `json:"warn_info"`
}

func (c *NmController) Post4101() {
	body, _ := ioutil.ReadAll(c.Ctx.Request.Body)
	var respJSON map[string]interface{}
	if err := json.Unmarshal([]byte(string(body)), &respJSON); err != nil {
		utils.ErrorLog("接口返回数据解析JSON失败: %v", err)
		return
	}
	struct4101UserJSONBytes, _ := json.Marshal(respJSON["struct4101"])
	var struct4101 service.Struct4101
	if err := json.Unmarshal(struct4101UserJSONBytes, &struct4101); err != nil {
		utils.ErrorLog("解析失败：%v", err)
		return
	}
	ppUserJSONBytes, _ := json.Marshal(respJSON["pp"])
	var pp models.PublicParams
	if err := json.Unmarshal(ppUserJSONBytes, &pp); err != nil {
		utils.ErrorLog("解析失败：%v", err)
		return
	}
	result, _ := service.Gdyb4101fornm(struct4101, pp.SecretKey, pp.FixmedinsName, pp.OpterName, pp.FixmedinsCode, pp.InsuplcAdmdvs, pp.MdtrtareaAdmvs, 0,0)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
		fmt.Println(dat)
	} else {
		fmt.Println(err)
	}

	saveJsLog(result, "", "4101", "上传明细清单", pp.FixmedinsName)
	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
	})
}

func (c *NmController) Post5203() {
	fmt.Println("------")
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	psn_no := c.GetString("psn_no")
	mdtrt_id := c.GetString("mdtrt_id")
	setl_id := c.GetString("setl_id")
	fmt.Println("------")
	bp := models.BaseParams{
		SecretKey:      secret_key,
		FixmedinsCode:  fixmedins_code,
		InsuplcAdmdvs:  insuplc_admdvs,
		MdtrtareaAdmvs: mdtrtarea_admvs,
		OrgName:        org_name,
		Doctor:         doctor,
	}
	bps := models.BusinessParams{
		PsnNo:   psn_no,
		MdtrtId: mdtrt_id,
		SetlId:  setl_id,
	}
	result := service.ZHyb5203(bp, bps)
	saveJsLog(result, "", "5203", "结算单", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {

	} else {

	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
	})
}
func (c *NmController) Post4102() {
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	psn_no := c.GetString("psn_no")
	mdtrt_id := c.GetString("mdtrt_id")
	setl_id := c.GetString("setl_id")
	stas_type := c.GetString("stas_type")

	bp := models.BaseParams{
		SecretKey:      secret_key,
		FixmedinsCode:  fixmedins_code,
		InsuplcAdmdvs:  insuplc_admdvs,
		MdtrtareaAdmvs: mdtrtarea_admvs,
		OrgName:        org_name,
		Doctor:         doctor,
	}
	bps := models.BusinessParams{
		PsnNo:    psn_no,
		MdtrtId:  mdtrt_id,
		SetlId:   setl_id,
		StasType: stas_type,
	}
	result := service.ZHyb4102(bp, bps)
	saveJsLog(result, "", "4102", "确认结算清单", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {

	} else {

	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
	})
}
func (c *NmController) Post4103() {
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	psn_no := c.GetString("psn_no")
	mdtrt_id := c.GetString("mdtrt_id")
	setl_id := c.GetString("setl_id")
	bp := models.BaseParams{
		SecretKey:      secret_key,
		FixmedinsCode:  fixmedins_code,
		InsuplcAdmdvs:  insuplc_admdvs,
		MdtrtareaAdmvs: mdtrtarea_admvs,
		OrgName:        org_name,
		Doctor:         doctor,
	}
	bps := models.BusinessParams{
		PsnNo:   psn_no,
		MdtrtId: mdtrt_id,
		SetlId:  setl_id,
	}
	result := service.ZHyb4103(bp, bps)
	result2 := service.ZHyb4104(bp, bps)

	saveJsLog(result, "", "4103", "查询结算清单", org_name)
	saveJsLog(result2, "", "4104", "指控结算清单", org_name)

	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {

	} else {

	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
	})
}
func (c *NmController) Post4104() {
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	psn_no := c.GetString("psn_no")
	mdtrt_id := c.GetString("mdtrt_id")
	setl_id := c.GetString("setl_id")
	bp := models.BaseParams{
		SecretKey:      secret_key,
		FixmedinsCode:  fixmedins_code,
		InsuplcAdmdvs:  insuplc_admdvs,
		MdtrtareaAdmvs: mdtrtarea_admvs,
		OrgName:        org_name,
		Doctor:         doctor,
	}
	bps := models.BusinessParams{
		PsnNo:   psn_no,
		MdtrtId: mdtrt_id,
		SetlId:  setl_id,
	}
	result := service.ZHyb4104(bp, bps)
	saveJsLog(result, "", "4104", "质控结算清单结果", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {

	} else {

	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
	})
}


func (c *NmController) Post1101() {
	certNo := c.GetString("cert_no")
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	id_card_type, _ := c.GetInt64("id_card_type")
	card_sn := c.GetString("card_sn")
	certificates := c.GetString("certificates")
	name := c.GetString("name")
	certificate, _ := strconv.ParseInt(certificates, 10, 64)
	result, request_log, result_log := service.ZHGdyb1101(certNo, org_name, doctor, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, id_card_type, card_sn, certificate, name,0)

	saveJsLog(result_log, request_log, "1101", "查询个人信息", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {

	} else {

	}

	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {

	} else {

	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
		"log": dat2,
	})

}

func (c *NmController) Post2401() {
	body, _ := ioutil.ReadAll(c.Ctx.Request.Body)
	var respJSON map[string]interface{}
	if err := json.Unmarshal([]byte(string(body)), &respJSON); err != nil {
		utils.ErrorLog("接口返回数据解析JSON失败: %v", err)
		return
	}
	userJSONBytes, _ := json.Marshal(respJSON["struct_2401"])
	var struct2401 service.Struct2401
	if err := json.Unmarshal(userJSONBytes, &struct2401); err != nil {
		utils.ErrorLog("解析失败：%v", err)
		return
	}
	org_name := respJSON["org_name"].(string)
	fixmedins_code := respJSON["fixmedins_code"].(string)
	doctor := respJSON["doctor"].(string)
	insuplc_admdvs := respJSON["insuplc_admdvs"].(string)
	mdtrtarea_admvs := respJSON["mdtrtarea_admvs"].(string)
	secret_key := respJSON["secret_key"].(string)
	result, request_log := service.Hbyb2401(struct2401, secret_key, org_name, fixmedins_code, doctor, insuplc_admdvs, mdtrtarea_admvs)
	saveJsLog(result, request_log, "2401", "入院登记", org_name)
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {
	} else {
	}
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})

}

func (c *NmController) Post2404() {
	mdtrt_id := c.GetString("mdtrt_id")
	psn_no := c.GetString("psn_no")
	doctor := c.GetString("doctor")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	org_name := c.GetString("org_name")

	result, requestLog := service.Hbyb2404(mdtrt_id, psn_no, secret_key, org_name, fixmedins_code, doctor, insuplc_admdvs, mdtrtarea_admvs)
	saveJsLog(result, requestLog, "2404", "入院登记撤销", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(requestLog), &dat2); err == nil {
	} else {
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
		"log": dat2,
	})

}
func (c *NmController) Post2405() {
	mdtrt_id := c.GetString("mdtrt_id")
	psn_no := c.GetString("psn_no")
	doctor := c.GetString("doctor")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	org_name := c.GetString("org_name")

	result, requestLog := service.Hb2405(mdtrt_id, psn_no, secret_key, org_name, fixmedins_code, doctor, insuplc_admdvs, mdtrtarea_admvs)
	saveJsLog(result, requestLog, "2405", "出院登记撤销", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(requestLog), &dat2); err == nil {
	} else {
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
		"log": dat2,
	})

}
func (c *NmController) Post2402() {
	body, _ := ioutil.ReadAll(c.Ctx.Request.Body)
	var respJSON map[string]interface{}
	if err := json.Unmarshal([]byte(string(body)), &respJSON); err != nil {
		utils.ErrorLog("接口返回数据解析JSON失败: %v", err)
		return
	}
	userJSONBytes, _ := json.Marshal(respJSON["struct_2402"])
	var struct2402 service.Struct2402
	if err := json.Unmarshal(userJSONBytes, &struct2402); err != nil {
		utils.ErrorLog("解析失败：%v", err)
		return
	}
	org_name := respJSON["org_name"].(string)
	fixmedins_code := respJSON["fixmedins_code"].(string)
	doctor := respJSON["doctor"].(string)
	insuplc_admdvs := respJSON["insuplc_admdvs"].(string)
	mdtrtarea_admvs := respJSON["mdtrtarea_admvs"].(string)
	secret_key := respJSON["secret_key"].(string)
	result, request_log := service.Hb2402(struct2402, org_name, doctor, insuplc_admdvs, mdtrtarea_admvs, secret_key, fixmedins_code)
	saveJsLog(result, request_log, "2402", "出院", org_name)
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(request_log), &dat2); err == nil {
	} else {
	}
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2301() {

	body, _ := ioutil.ReadAll(c.Ctx.Request.Body)
	var respJSON map[string]interface{}
	if err := json.Unmarshal([]byte(string(body)), &respJSON); err != nil {
		utils.ErrorLog("接口返回数据解析JSON失败: %v", err)
		return
	}
	userJSONBytes, _ := json.Marshal(respJSON["customs"])
	var customs []*models.NewCustom
	if err := json.Unmarshal(userJSONBytes, &customs); err != nil {
		utils.ErrorLog("解析失败：%v", err)
		return
	}

	number := respJSON["number"].(string)

	chrg_bchno := respJSON["chrg_bchno"].(string)
	dept := respJSON["dept"].(string)
	dept_code := respJSON["dept_code"].(string)
	doctor_code := respJSON["doctor_code"].(string)

	doctor_name := respJSON["doctor_name"].(string)
	opertor := respJSON["opertor"].(string)

	org_name := respJSON["org_name"].(string)
	fixmedins_code := respJSON["fixmedins_code"].(string)
	insuplc_admdvs := respJSON["insuplc_admdvs"].(string)
	mdtrtarea_admvs := respJSON["mdtrtarea_admvs"].(string)
	secret_key := respJSON["secret_key"].(string)
	med_type := respJSON["med_type"].(string)
	//med_type := strconv.FormatInt(int64(respJSON["med_type"].(float64)), 10)
	psn_no := respJSON["psn_no"].(string)

	result, requestLog := service.Hb2301A(psn_no, number, customs, chrg_bchno, org_name, doctor_name, dept, fixmedins_code, dept_code, doctor_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, med_type, opertor)
	saveJsLog(result, requestLog, "2301", "上传明细", org_name)

	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(requestLog), &dat2); err == nil {
	} else {
	}
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2302() {
	mdtrt_id := c.GetString("mdtrtId")
	psn_no := c.GetString("psn_no")
	number := c.GetString("feedetl_sn")
	doctor := c.GetString("doctor")
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	org_name := c.GetString("org_name")
	refund_type, _ := c.GetInt64("refund_type")

	result, requestLog := service.Hb2302(psn_no, mdtrt_id, org_name, doctor, insuplc_admdvs, mdtrtarea_admvs, secret_key, fixmedins_code, number, refund_type)
	saveJsLog(result, requestLog, "2302", "退明细", org_name)
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(requestLog), &dat2); err == nil {
	} else {
	}
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2303() {
	mdtrt_id := c.GetString("mdtrt_id")
	psn_no := c.GetString("psn_no")
	chrg_bchno := c.GetString("chrg_bchno")
	cert_no := c.GetString("cert_no")
	insutype_type := c.GetString("insutype_type")

	allTotal := c.GetString("total")
	id_card_type, _ := c.GetInt64("id_card_type")

	doctor := c.GetString("doctor")
	certificates, _ := c.GetInt64("certificates")

	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	org_name := c.GetString("org_name")

	result, src_resquest := service.Hb2303(psn_no, mdtrt_id, chrg_bchno, cert_no, insutype_type, allTotal, org_name, doctor, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, "0", id_card_type, 0, 0, 0, 0, certificates)
	saveJsLog(result, src_resquest, "2303", "预结算", org_name)
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(src_resquest), &dat2); err == nil {
	} else {
	}
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2304() {
	mdtrt_id := c.GetString("mdtrt_id")
	psn_no := c.GetString("psn_no")
	chrg_bchno := c.GetString("chrg_bchno")
	cert_no := c.GetString("cert_no")
	insutype_type := c.GetString("insutype_type")

	allTotal := c.GetString("total")
	id_card_type, _ := c.GetInt64("id_card_type")

	doctor := c.GetString("doctor")
	certificates, _ := c.GetInt64("certificates")

	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	org_name := c.GetString("org_name")
	fapiao_number := c.GetString("fapiao_number")
	acct_used_flag := c.GetString("acct_used_flag")

	result, src_resquest := service.Hb2304(psn_no, mdtrt_id, chrg_bchno, cert_no, insutype_type, allTotal, org_name, doctor, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, "0", id_card_type, 0, 0, 0, 0, certificates, fapiao_number, acct_used_flag)
	saveJsLog(result, src_resquest, "2304", "住院结算", org_name)
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(src_resquest), &dat2); err == nil {
	} else {
	}
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}
func (c *NmController) Post2305() {
	mdtrt_id := c.GetString("mdtrt_id")
	psn_no := c.GetString("psn_no")
	doctor := c.GetString("doctor")
	setl_id := c.GetString("setl_id")

	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	org_name := c.GetString("org_name")

	result, requestLog := service.Hb2305(psn_no, mdtrt_id, setl_id, org_name, doctor, secret_key, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs)
	saveJsLog(result, requestLog, "2305", "退费", org_name)
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(requestLog), &dat2); err == nil {
	} else {
	}
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
	} else {
	}
	c.ServeSuccessJSON(map[string]interface{}{
		"pre":         dat,
		"request_log": dat2,
	})
}

func (c *NmController) Get2503() {

}

func (c *NmController) ReadCard() {
	fixmedins_code := c.GetString("fixmedins_code")
	secret_key := c.GetString("secret_key")
	org_name := c.GetString("org_name")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	id_card_type := c.GetString("id_card_type")
	operator_id := c.GetString("operator_id")
	operator := c.GetString("operator")
	is_settle := c.GetString("is_settle")

	switch id_card_type {
	case "1":
		if initFlag == 0 {
			c.TestGetBasBaseInit()
		}
		pBusiCardInfo := c.GetBasBaseInfo(fixmedins_code, mdtrtarea_admvs, operator, operator_id, org_name)
		basStr := Remove0000(pBusiCardInfo)

		if len(basStr) == 0 {
			c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeReadCardException)
			return
		}

		var dat2 map[string]interface{}
		if err := json.Unmarshal([]byte(basStr), &dat2); err == nil {
			fmt.Println(dat2)
		} else {
			fmt.Println(err)
		}

		userJSONBytes, _ := json.Marshal(dat2)
		var res ReadCardResult
		if err := json.Unmarshal(userJSONBytes, &res); err != nil {
			utils.ErrorLog("解析失败：%v", err)
			c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeDataException)
			return
		}

		fmt.Println(basStr)
		bas := strings.Split(res.Output.CardInfo, "|")
		basNumber := bas[1]
		fmt.Println(basNumber)
		card_sn := bas[3]
		fmt.Println(card_sn)
		cardNumber := bas[2]
		name := bas[4]

		result := service.Gdyb1101G(basNumber, org_name, operator, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, 1, card_sn, 1, name, cardNumber)
		var dat map[string]interface{}
		if err := json.Unmarshal([]byte(result), &dat); err == nil {
			fmt.Println(dat)
		} else {
			fmt.Println(err)
		}

		userJSONBytes2, _ := json.Marshal(dat)
		var res2 ResultTwo
		if err := json.Unmarshal(userJSONBytes2, &res2); err != nil {
			utils.ErrorLog("解析失败：%v", err)
			c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeDataException)
			return
		}
		infocode, _ := strconv.ParseInt(res2.Infcode, 10, 64)

		if infocode == 0 {
			c.ServeSuccessJSON(map[string]interface{}{
				"status":         "0",
				"card_info":      res.Output.CardInfo,
				"busi_card_info": pBusiCardInfo,
				"result":         res2,
				"type":           "1",
			})

		} else {
			c.ServeSuccessJSON(map[string]interface{}{
				"status": "-1",
			})
		}

		break
	case "4": //电子凭证
		//c.GetELeInfo()
		var result_info string
		if len(is_settle) > 0 {
			_, result_info = c.GetELeInfo(fixmedins_code, operator_id, operator)
		} else {
			_, result_info = c.GetELeInfoThree(fixmedins_code, operator_id, operator)
		}
		//if result_code == "0000" {
		var ele ELeData
		err := json.Unmarshal([]byte(result_info), &ele)
		if err != nil {
			utils.ErrorLog("解析失败：%v", err)
		}
		token := ele.Data.EcToken
		fmt.Println(token)
		if len(token) > 0 {
			result, _ := service.Gdyb1101ForEleCert(org_name, operator, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, token, ele.Data.UserName, ele.Data.IdNo)
			var dat map[string]interface{}
			if err := json.Unmarshal([]byte(result), &dat); err == nil {
				fmt.Println(dat)
			} else {
				fmt.Println(err)
			}
			userJSONBytes, _ := json.Marshal(dat)
			var res ResultTwo
			if err := json.Unmarshal(userJSONBytes, &res); err != nil {
				utils.ErrorLog("解析失败：%v", err)
				c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeDataException)
				return
			}

			infocode, _ := strconv.ParseInt(res.Infcode, 10, 64)

			if infocode == 0 {
				c.ServeSuccessJSON(map[string]interface{}{
					"status":         "0",
					"card_info":      result_info,
					"busi_card_info": result_info,
					"token":          token,
					"result":         dat,
				})
			} else {
				c.ServeSuccessJSON(map[string]interface{}{
					"status": "-1",
				})

			}
		} else {
			c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeHisFailedException)
			return
		}

		break
	case "5": //电子凭证
		//c.GetELeInfoTwo(fixmedins_code, operator_id, operator)
		//_, pBusiCardInfo := c.GetELeInfoTwo(fixmedins_code, operator_id, operator)

		//var ele ELeData
		//err := json.Unmarshal([]byte(pBusiCardInfo), &ele)
		//if err != nil {
		//	utils.ErrorLog("解析失败：%v", err)
		//}
		//token := ele.Data.EcToken
		//fmt.Println(token)
		//if len(token) > 0 {
		//	result, _ := service.Gdyb1101ForEleCert(org_name, operator, fixmedins_code, insuplc_admdvs, mdtrtarea_admvs, secret_key, token, ele.Data.IdNo, ele.Data.UserName)
		//	var dat map[string]interface{}
		//	if err := json.Unmarshal([]byte(result), &dat); err == nil {
		//		fmt.Println(dat)
		//	} else {
		//		fmt.Println(err)
		//	}
		//	userJSONBytes, _ := json.Marshal(dat)
		//	var res ResultTwo
		//	if err := json.Unmarshal(userJSONBytes, &res); err != nil {
		//		utils.ErrorLog("解析失败：%v", err)
		//		c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeDataException)
		//		return
		//	}
		//
		//	infocode, _ := strconv.ParseInt(res.Infcode, 10, 64)
		//
		//	if infocode == 0 {
		//
		//		c.ServeSuccessJSON(map[string]interface{}{
		//			"status":         "0",
		//			"card_info":      pBusiCardInfo,
		//			"busi_card_info": pBusiCardInfo,
		//			"token":          token,
		//			"result":         dat,
		//		})
		//
		//	} else {
		//		c.ServeSuccessJSON(map[string]interface{}{
		//			"status": "-1",
		//		})
		//
		//	}
		//} else {
		//	c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeHisFailedException)
		//	return
		//}
		//break

	}

}

var initFlag int64 = 0

func (c *NmController) GetELeInfoTwo(code string, operator_id string, operator_name string) (string, string) {
	DllDef := syscall.MustLoadDLL("NationECCode.dll")
	readCard := DllDef.MustFindProc("NationEcTrans")
	fmt.Println(readCard)
	fmt.Println("!!!!!")
	pBusiCardInfo := make([]byte, 1024*10)
	input := make(map[string]interface{})
	inputData := make(map[string]interface{})
	inputData["orgId"] = code
	inputData["businessType"] = "01101"
	inputData["operatorId"] = operator_id
	inputData["operatorName"] = operator_name
	inputData["officeId"] = "001"
	inputData["officeName"] = "血透室"
	inputData["deviceType"] = ""
	input["data"] = inputData
	input["orgId"] = code
	input["transType"] = "ec.query"

	bytesData, _ := json.Marshal(input)
	//gdyb_url := beego.AppConfig.String("gdyb_url")
	fmt.Println(string(bytesData))
	url := "http://10.38.22.15:8081" + "/localcfc/api/hsecfc/localQrCodeQuery"
	ret2, aa, bb := readCard.Call(StrPtr(url), (uintptr)(unsafe.Pointer(&bytesData[0])), (uintptr)(unsafe.Pointer(&pBusiCardInfo[0])))
	fmt.Println(aa)
	fmt.Println(bb)

	fmt.Println(ret2)
	fmt.Println(DeleteExtraSpace(string(pBusiCardInfo)))
	fmt.Println(":", ConvertToString(DeleteExtraSpace(string(pBusiCardInfo)), "gbk", "utf-8"))
	if ret2 != 0 {
		return "", ""
	}
	return DeleteExtraSpace(""), DeleteExtraSpace(string(pBusiCardInfo))
}

func (c *NmController) TestGetBasBaseInit() {
	DllDef := syscall.MustLoadDLL("HeaSecReadInfo.dll")
	Iinit := DllDef.MustFindProc("Init")
	//miConfig, _ := service.FindMedicalInsuranceInfo(c.GetAdminUserInfo().CurrentOrgId)
	str := make([]byte, 2048)
	inputData := make(map[string]interface{})
	inputData["IP"] = "tyjk.nm.hsip.gov.cn"
	inputData["PORT"] = 8090
	inputData["TIMEOUT"] = 180
	inputData["LOG_PATH"] = "C:\\log\\"
	//inputData["SFZ_DRIVER_TYPE"] = 0
	inputData["URL"] = "/uif-hsaf-med-api/api/medical/service"

	bytesData, _ := json.Marshal(inputData)
	fmt.Println(inputData)
	fmt.Println(bytesData)

	ret, _, err := Iinit.Call((uintptr)(unsafe.Pointer(&bytesData[0])), (uintptr)(unsafe.Pointer(&str[0])))
	if ret != 0 {
		fmt.Println("SSCard的报错原因:", err)
		fmt.Println("SSCard的运算结果为:", ret)
		fmt.Println("SSCard的返回结果为:", string(str))
		c.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeReadCardException)
		return
	}
	fmt.Println("SSCard的返回结果为:", string(str))

	result := int(ret)
	fmt.Println("SSCard的运算结果为1:", result)
	//initFlag = 1
	return
}
func (c *NmController) GetSFZBaseInfo() string {
	DllDef := syscall.MustLoadDLL("SSCard.dll")
	readCard := DllDef.MustFindProc("ReadSFZ")
	if readCard == nil {
		fmt.Println("readcard is nil")
		readCard = DllDef.MustFindProc("ReadSFZ")
	}

	str := make([]byte, 256)
	str1 := make([]byte, 256)
	r, _, _ := readCard.Call((uintptr)(unsafe.Pointer(&str[0])), IntPtr(1024), (uintptr)(unsafe.Pointer(&str1[0])), IntPtr(1024))

	fmt.Println(r)
	return string(str)
}
func (c *NmController) GetBasBaseInfo(fixmedins_code string, mdtrtarea_admvs string, opter_name string, opter_id string, fixmedins_name string) string {
	DllDef := syscall.MustLoadDLL("HeaSecReadInfo.dll")
	readCard := DllDef.MustFindProc("ReadCardBas")
	fmt.Println(readCard)
	fmt.Println("!!!!!")

	month := time.Unix(1557042972, 0).Format("1")
	year := time.Now().Format("2006")
	month = time.Now().Format("01")
	day := time.Now().Format("02")

	hour := time.Now().Format("15")
	min := time.Now().Format("04")
	sec := time.Now().Format("05")

	msec := time.Now().Format("000")
	timestamp := time.Now().Unix()

	tempTime := time.Unix(timestamp, 0)
	//timeFormat := tempTime.Format("20060102150405")
	timeFormatOne := tempTime.Format("2006-01-02 15:04:05")
	//randNum := rand.New(rand.NewSource(time.Now().UnixNano())).Int31n(10000)

	inputData := make(map[string]interface{})
	inputData["infno"] = "1199"
	//inputData["msgid"] = "7021"
	inputData["msgid"] = fixmedins_code + year + month + day + hour + min + sec + msec + "0" // 发送方报文 ID
	inputData["mdtrtarea_admvs"] = mdtrtarea_admvs
	inputData["insuplc_admdvs"] = "" // 发送方报文 ID
	// 发送方报文 ID
	inputData["recer_sys_code"] = "01"
	inputData["dev_no"] = ""
	inputData["dev_safe_info"] = ""
	inputData["cainfo"] = ""
	inputData["signtype"] = "SM3"
	inputData["infver"] = "V1.0"
	inputData["opter_type"] = "1"
	inputData["opter"] = opter_id
	inputData["opter_name"] = opter_name
	inputData["inf_time"] = timeFormatOne
	inputData["fixmedins_code"] = fixmedins_code
	inputData["fixmedins_name"] = fixmedins_name
	inputData["sign_no"] = ""

	bytesData, _ := json.Marshal(inputData)
	fmt.Println(string(bytesData))
	pBusiCardInfo := make([]byte, 8192)
	ret2, _, _ := readCard.Call((uintptr)(unsafe.Pointer(&bytesData[0])), (uintptr)(unsafe.Pointer(&pBusiCardInfo[0])))
	fmt.Println(ret2)
	fmt.Println(DeleteExtraSpace(string(pBusiCardInfo)))
	fmt.Println(":", ConvertToString(DeleteExtraSpace(string(pBusiCardInfo)), "gbk", "utf-8"))
	if ret2 != 0 {
		return ""
	}
	return DeleteExtraSpace(string(pBusiCardInfo))
}
func (c *NmController) GetELeInfo(code string, operator_id string, operator_name string) (string, string) {
	// WebSocket服务器地址
	serverURL := "ws://127.0.0.1:8899"

	// 解析WebSocket服务器地址
	u, err := url.Parse(serverURL)
	if err != nil {
		log.Fatal(err)
	}

	// 建立WebSocket连接
	conn, _, err := websocket.DefaultDialer.Dial(u.String(), nil)
	if err != nil {
		log.Fatal(err)
	}
	defer conn.Close()
	input2 := make(map[string]interface{})

	input := make(map[string]interface{})
	inputData := make(map[string]interface{})
	inputData["orgId"] = code
	inputData["businessType"] = "01101"
	inputData["operatorId"] = operator_id
	inputData["operatorName"] = operator_name
	inputData["officeId"] = "001"
	inputData["officeName"] = "血透室"
	inputData["deviceType"] = ""
	input["data"] = inputData
	input["orgId"] = code
	input["transType"] = "ec.query"
	input2["url"] = "http://10.38.22.15:8081/localcfc/api/hsecfc/localQrCodeQuery"
	input2["indata"] = input

	bytesData, _ := json.Marshal(input2)
	err = conn.WriteMessage(websocket.TextMessage, bytesData)
	if err != nil {
		fmt.Println(err)
	}

	// 接收消息
	_, receivedMessage, err := conn.ReadMessage()
	if err != nil {
		fmt.Println(err)
	}

	return "", string(receivedMessage)
}
func (c *NmController) GetELeInfoThree(code string, operator_id string, operator_name string) (string, string) {
	// WebSocket服务器地址
	serverURL := "ws://127.0.0.1:8899"

	// 解析WebSocket服务器地址
	u, err := url.Parse(serverURL)
	if err != nil {
		log.Fatal(err)
	}

	// 建立WebSocket连接
	conn, _, err := websocket.DefaultDialer.Dial(u.String(), nil)
	if err != nil {
		log.Fatal(err)
	}
	defer conn.Close()
	input2 := make(map[string]interface{})

	input := make(map[string]interface{})
	inputData := make(map[string]interface{})
	inputData["orgId"] = code
	inputData["businessType"] = "01301"
	inputData["operatorId"] = operator_id
	inputData["operatorName"] = operator_name
	inputData["officeId"] = "001"
	inputData["officeName"] = "血透室"
	inputData["deviceType"] = ""
	input["data"] = inputData
	input["orgId"] = code
	input["transType"] = "ec.query"
	input2["url"] = "http://10.38.22.15:8081/localcfc/api/hsecfc/localQrCodeQuery"
	input2["indata"] = input

	bytesData, _ := json.Marshal(input2)
	err = conn.WriteMessage(websocket.TextMessage, bytesData)
	if err != nil {
		fmt.Println(err)
	}

	// 接收消息
	_, receivedMessage, err := conn.ReadMessage()
	if err != nil {
		fmt.Println(err)
	}

	return "", string(receivedMessage)
}

func IntPtr(n int) uintptr {
	return uintptr(n)
}
func StrPtr(s string) uintptr {
	return uintptr(unsafe.Pointer(syscall.StringBytePtr(s)))
}

type Charset string

const (
	UTF8    = Charset("UTF-8")
	GB18030 = Charset("GB18030")
)

func ConvertToString(src string, srcCode string, tagCode string) string {
	srcCoder := mahonia.NewDecoder(srcCode)
	srcResult := srcCoder.ConvertString(src)
	tagCoder := mahonia.NewDecoder(tagCode)
	_, cdata, _ := tagCoder.Translate([]byte(srcResult), true)
	result := string(cdata)
	return result
}
func DeleteExtraSpace(s string) string {
	//删除字符串中的多余空格，有多个空格时，仅保留一个空格
	s1 := strings.Replace(s, "  ", " ", -1)      //替换tab为空格
	regstr := "\\s{2,}"                          //两个及两个以上空格的正则表达式
	reg, _ := regexp.Compile(regstr)             //编译正则表达式
	s2 := make([]byte, len(s1))                  //定义字符数组切片
	copy(s2, s1)                                 //将字符串复制到切片
	spc_index := reg.FindStringIndex(string(s2)) //在字符串中搜索
	for len(spc_index) > 0 {                     //找到适配项
		s2 = append(s2[:spc_index[0]+1], s2[spc_index[1]:]...) //删除多余空格
		spc_index = reg.FindStringIndex(string(s2))            //继续在字符串中搜索
	}
	return string(s2)
}
func Remove0000(s string) string {
	str := make([]rune, 0, len(s))
	for _, v := range []rune(s) {
		if v == 0 {
			continue
		}
		str = append(str, v)
	}
	return string(str)
}
func saveJsLog(result string, request string, infno string, desc string, org_name string) {

	//org_id, _ := beego.AppConfig.Int64("org_id")
	//miConfig, _ := service.FindMedicalInsuranceInfo(org_id)
	dir := org_name + "日志"
	utils.Mkdir(dir)
	month := time.Unix(1557042972, 0).Format("1")
	year := time.Now().Format("2006")
	month = time.Now().Format("01")
	day := time.Now().Format("02")
	hour := time.Now().Format("15")
	min := time.Now().Format("04")
	sec := time.Now().Format("05")

	result_time := year + "-" + month + "-" + day + " " + hour + ":" + min + ":" + sec

	file := org_name + "_" + year + month + day + "_log"
	file_name := file + ".txt"
	file_path := org_name + "日志" + "/" + file_name
	exist, _ := utils.PathExists(file_path)
	if exist { //存在
		fmt.Println("存在")
		f, err := os.OpenFile(file_path, os.O_WRONLY, 0644)
		if err != nil {
			fmt.Println("read fail")
		}
		content := "\r\n" + "\r\n" + "\r\n" + result_time + " " + "【 " + desc + infno + "入参" + " 】：" + "\r\n" + request + "\r\n" + result_time + " " + "【 " + desc + infno + "出参" + " 】：" + "\r\n" + result
		n, _ := f.Seek(0, 2)
		_, err = f.WriteAt([]byte(content), n)

	} else { //不存在
		fmt.Println("文件不存在，创建文件")
		f, err := os.Create(org_name + "日志" + "/" + file_name)
		defer f.Close()
		if err != nil {
		} else {
			_, err = f.Write([]byte("记录日志"))
		}
	}

}

func (c *NmController) Get3201() {
	insutype := c.GetString("insutype")
	clrType := c.GetString("clr_type")
	setlOptins := c.GetString("setl_optins")
	stmtBegndate := c.GetString("stmt_begndate")
	stmtEnddate := c.GetString("stm_enddate")
	medfeeSumamt, _ := c.GetFloat("medfee_sumamt", 0)
	fundPaySumamt, _ := c.GetFloat("fund_pay_sumamt", 0)
	acctPay, _ := c.GetFloat("acct_pay", 0)
	fixmedinsSetlCnt, _ := c.GetInt64("fixmedins_setl_cnt", 0)
	fixmedins_code := c.GetString("fixmedins_code")
	insuplc_admdvs := c.GetString("insuplc_admdvs")
	mdtrtarea_admvs := c.GetString("mdtrtarea_admvs")
	secret_key := c.GetString("secret_key")
	org_name := c.GetString("org_name")
	doctor := c.GetString("doctor")

	baseParams := models.BaseParams{
		SecretKey:      secret_key,
		FixmedinsCode:  fixmedins_code,
		InsuplcAdmdvs:  insuplc_admdvs,
		MdtrtareaAdmvs: mdtrtarea_admvs,
		OrgName:        org_name,
		Doctor:         doctor,
	}
	businessParams := models.BusinessParams{
		Insutype:         insutype,
		ClrType:          clrType,
		SetlOptins:       setlOptins,
		StmtBegndate:     stmtBegndate,
		StmtEnddate:      stmtEnddate,
		MedfeeSumamt:     medfeeSumamt,
		FundPaySumamt:    fundPaySumamt,
		AcctPay:          acctPay,
		FixmedinsSetlCnt: fixmedinsSetlCnt,
	}
	result := service.Gdyb3201(baseParams, businessParams,0)
	saveJsLog(result, "", "3201", "对总账", org_name)
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
		fmt.Println(dat)
	} else {
		fmt.Println(err)
	}

	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
	})
}
func (c *NmController) Get2601() {
	result := service.Gdyb26011("150000CFSJM100000100135084", "H15049901371202210111721190000", "2305", "赤峰费森血液透析中心", "李彩星", "H15049901371", "150402", "150499", "MSDBYGxXm1Mtyi3PtOUB7n1ktcxwyW57\n")
	var dat map[string]interface{}
	if err := json.Unmarshal([]byte(result), &dat); err == nil {
		fmt.Println(dat)
	} else {
		fmt.Println(err)
	}
	result2 := service.Gdyb26011("150000CFSJM100000100135084", "H15049901371202209281143070000", "2304", "赤峰费森血液透析中心", "李彩星", "H15049901371", "150402", "150499", "MSDBYGxXm1Mtyi3PtOUB7n1ktcxwyW57\n")
	var dat2 map[string]interface{}
	if err := json.Unmarshal([]byte(result2), &dat2); err == nil {
		fmt.Println(dat2)
	} else {
		fmt.Println(err)
	}

	c.ServeSuccessJSON(map[string]interface{}{
		"pre": dat,
	})
}
func ConvertByte2String(byte []byte, charset Charset) string {

	var str string
	switch charset {
	case GB18030:
		decodeBytes, _ := simplifiedchinese.GB18030.NewDecoder().Bytes(byte)
		str = string(decodeBytes)
	case UTF8:
		fallthrough
	default:
		str = string(byte)
	}

	return str
}
